@font-face{font-family:"Inter";font-style:normal;font-weight:500;src:local(""),url(/static/media/inter-v7-latin-500.09888c3a.woff2) format("woff2"),url(/static/media/inter-v7-latin-500.8a9f174e.woff) format("woff")}@font-face{font-family:"Inter";font-style:normal;font-weight:400;src:local(""),url(/static/media/inter-v7-latin-regular.5e6a773d.woff2) format("woff2"),url(/static/media/inter-v7-latin-regular.cefb4aac.woff) format("woff")}@font-face{font-family:"Inter";font-style:normal;font-weight:600;src:local(""),url(/static/media/inter-v7-latin-600.5ac6cfcf.woff2) format("woff2"),url(/static/media/inter-v7-latin-600.7927acf4.woff) format("woff")}@font-face{font-family:"Inconsolata";font-style:normal;font-weight:400;src:local(""),url(/static/media/inconsolata-v21-latin-regular.5defbb9e.woff2) format("woff2"),url(/static/media/inconsolata-v21-latin-regular.1b6a5f20.woff) format("woff")}@font-face{font-family:"Inconsolata";font-style:normal;font-weight:500;src:local(""),url(/static/media/inconsolata-v21-latin-500.0f9a2c7c.woff2) format("woff2"),url(/static/media/inconsolata-v21-latin-500.c20be44f.woff) format("woff")}@font-face{font-family:"Inconsolata";font-style:normal;font-weight:600;src:local(""),url(/static/media/inconsolata-v21-latin-600.c5f991ab.woff2) format("woff2"),url(/static/media/inconsolata-v21-latin-600.6edcb0b3.woff) format("woff")}
/*# sourceMappingURL=main.99b1a7e5.chunk.css.map */